// --------------------------------------------------------------------
// Author  : mashimonator
// Create  : 2009/09/28
// Update  : 2009/09/28
//         : 2011/05/16 アイコンの付加を特定IDを持つ要素に限定できるように修正
// Description : リンクに対応したアイコンを付加する
// --------------------------------------------------------------------

var addIcon2Links = {
	//-----------------------------------------
	// 設定値
	//-----------------------------------------
	config : {
		// アイコン付加の対象とする要素のIDを指定する(未指定の場合は全要素が対象)
		extractId : '',
		// アイコン配置ディレクトリ（ルート・絶対・相対パスで指定可能）
		imageDir : './images/',
		// アイコンを付加する拡張子 [ 拡張子, 画像ファイル名, クラス名 ]
		extension : [
			[ '.pdf', 'ico_pdf.png', 'addIconPdf' ],
			[ '.xls', 'ico_xls.png', 'addIconXls' ],
			[ '.xlsx', 'ico_xls.png', 'addIconXls' ],
			[ '.doc', 'ico_doc.png', 'addIconDoc' ],
			[ '.docx', 'ico_doc.png', 'addIconDoc' ],
			[ '.ppt', 'ico_ppt.png', 'addIconPpt' ],
			[ '.pptx', 'ico_ppt.png', 'addIconPpt' ],
			[ '.zip', 'ico_zip.png', 'addIconZip' ],
			[ '.lzh', 'ico_zip.png', 'addIconZip' ],
			[ '.cab', 'ico_zip.png', 'addIconZip' ],
			[ '.txt', 'ico_txt.png', 'addIconTxt' ]
		],
		// 上記以外でアイコンを付加するリンク（true：付加する／false：付加しない）
		externalFlag : [ true, 'ico_external.png', 'addIconExternal' ], // 外部サイトへのリンク
		mailFlag : [ true, 'ico_mail.png', 'addIconMail' ], // mailto
		httpFlag : [ true, 'ico_http.png', 'addIconHttp' ], // httpへのリンク（httpsページ内のみ有効）
		httpsFlag : [ true, 'ico_https.png', 'addIconHttps' ], // httpsへのリンク（httpページ内のみ有効）
		blankFlag : [ true, 'ico_blank.png', 'addIconBlank' ], // 別ウィンドウ
		// httpのドメイン(httpsとドメインが変わる場合は文字列で設定)
		httpDomain : location.hostname,
		// httpsのドメイン(httpとドメインが変わる場合は文字列で設定)
		httpsDomain : location.hostname,
		// 該当ページのURL（変更不可）
		url : location.href
	},
	//-----------------------------------------
	// 初期設定
	//-----------------------------------------
	initialize : function() {
		// CSSセット
		addIcon2Links.addEvent( window, 'load',  addIcon2Links.setStyle );
		// Loadイベントにアイコン付加処理をセット
		addIcon2Links.addEvent( window, 'load',  addIcon2Links.setIcon );
	},
	//-----------------------------------------
	// CSSをセットする
	//-----------------------------------------
	setStyle : function() {
		// アイコン配置ディレクトリの編集
		var imagePath = '';
		if ( addIcon2Links.config.imageDir.match(/^http:/) || addIcon2Links.config.imageDir.match(/^https:/) ) {
			// アイコン配置ディレクトリが絶対パスの場合
			imagePath = addIcon2Links.config.imageDir;
		} else if ( addIcon2Links.config.imageDir.match(/^[/]/) ) {
			// アイコン配置ディレクトリがルートパスの場合（絶対パスに置き換え）
			if ( addIcon2Links.config.url.match(/^https:/) ) {
				imagePath = 'https://' + addIcon2Links.config.httpsDomain + addIcon2Links.config.imageDir;
			} else {
				imagePath = 'http://' + addIcon2Links.config.httpDomain + addIcon2Links.config.imageDir;
			}
		} else {
			// アイコン配置ディレクトリが相対パスの場合
			imagePath = addIcon2Links.config.imageDir;
		}
		// extension
		for (var i = 0, len = addIcon2Links.config.extension.length; i < len; i++) {
			addIcon2Links.addCssRule('a.' + addIcon2Links.config.extension[i][2], 'background:url(' + imagePath + addIcon2Links.config.extension[i][1] + ') no-repeat right center; padding-right:20px;');
		}
		// external
		if ( addIcon2Links.config.externalFlag[0] ) {
			addIcon2Links.addCssRule('a.' + addIcon2Links.config.externalFlag[2], 'background:url(' + imagePath + addIcon2Links.config.externalFlag[1] + ') no-repeat right center; padding-right:20px;');
		}
		// mailto
		if ( addIcon2Links.config.mailFlag[0] ) {
			addIcon2Links.addCssRule('a.' + addIcon2Links.config.mailFlag[2], 'background:url(' + imagePath + addIcon2Links.config.mailFlag[1] + ') no-repeat right center; padding-right:20px;');
		}
		// http
		if ( addIcon2Links.config.httpFlag[0] ) {
			addIcon2Links.addCssRule('a.' + addIcon2Links.config.httpFlag[2], 'background:url(' + imagePath + addIcon2Links.config.httpFlag[1] + ') no-repeat right center; padding-right:20px;');
		}
		// https
		if ( addIcon2Links.config.httpsFlag[0] ) {
			addIcon2Links.addCssRule('a.' + addIcon2Links.config.httpsFlag[2], 'background:url(' + imagePath + addIcon2Links.config.httpsFlag[1] + ') no-repeat right center; padding-right:20px;');
		}
		// blank
		if ( addIcon2Links.config.blankFlag[0] ) {
			addIcon2Links.addCssRule('a.' + addIcon2Links.config.blankFlag[2], 'background:url(' + imagePath + addIcon2Links.config.blankFlag[1] + ') no-repeat right center; padding-right:20px;');
		}
	},
	//-----------------------------------------
	// リンクにアイコンをセットする
	//-----------------------------------------
	setIcon : function() {
		var targetElm = null;
		if ( addIcon2Links.config.extractId ) {
			targetElm = document.getElementById(addIcon2Links.config.extractId);
			if ( !targetElm ) {
				return;
			}
		} else {
			targetElm = document;
		}
		var elements = targetElm.getElementsByTagName('A');
		for (var i = 0, len = elements.length; i < len; i++) {
			// リンク形式のチェック
			if ( !addIcon2Links.checkTextLink(elements[i]) ) {
				continue;
			}
			var setFlag = false;
			var href = elements[i].getAttribute('href');
			if ( !href ) {
				continue;
			}
			// extension
			for (var x = 0, len2 = addIcon2Links.config.extension.length; x < len2; x++) {
				var reg = new RegExp( addIcon2Links.config.extension[x][0] + '$', 'i' );
				if ( href.match(reg) ) {
					elements[i].className += ' ' + addIcon2Links.config.extension[x][2];
					setFlag = true;
					break;
				}
			}
			// mailto
			if ( !setFlag && addIcon2Links.config.mailFlag[0] ) {
				if ( href.match(/^mailto:/i) ) {
					elements[i].className += ' ' + addIcon2Links.config.mailFlag[2];
					setFlag = true;
				}
			}
			// external
			if ( !setFlag && addIcon2Links.config.externalFlag[0] && addIcon2Links.config.httpDomain && addIcon2Links.config.httpsDomain ) {
				var reg = new RegExp( addIcon2Links.config.httpDomain );
				var reg2 = new RegExp( addIcon2Links.config.httpsDomain );
				if ( href.match(/^(http:|https:)/) && ( !href.match(reg) && !href.match(reg2) ) ) {
					elements[i].className += ' ' + addIcon2Links.config.externalFlag[2];
					setFlag = true;
				}
			}
			// http
			if ( !setFlag && addIcon2Links.config.httpFlag[0] && addIcon2Links.config.url.match(/^https:/) && addIcon2Links.config.httpDomain ) {
				var reg = new RegExp( addIcon2Links.config.httpDomain );
				if ( href.match(/^http:/) && href.match(reg) ) {
					elements[i].className += ' ' + addIcon2Links.config.httpFlag[2];
					setFlag = true;
				}
			}
			// https
			if ( !setFlag && addIcon2Links.config.httpsFlag[0] && addIcon2Links.config.url.match(/^http:/) && addIcon2Links.config.httpsDomain ) {
				var reg = new RegExp( addIcon2Links.config.httpsDomain );
				if ( href.match(/^https:/) && href.match(reg) ) {
					elements[i].className += ' ' + addIcon2Links.config.httpsFlag[2];
					setFlag = true;
				}
			}
			// blank
			if ( !setFlag && addIcon2Links.config.blankFlag[0] ) {
				var target = elements[i].getAttribute('target');
				if ( target && target.match('_blank') ) {
					elements[i].className += ' ' + addIcon2Links.config.blankFlag[2];
				}
			}
		}
	},
	//-----------------------------------------
	// スタイルシートに規則を追加する
	//-----------------------------------------
	addCssRule : function ( selector, declarations ) {
		var sheets = document.styleSheets;
		if ( sheets ) {
			if ( sheets.length < 1 ) {
				// 外部読み込みのスタイルシートが無い場合
				var style = document.createElement('style');
				style.setAttribute('type', 'text/css');
				style.innerHTML += selector + '{' + declarations + '}';
				var head = document.getElementsByTagName('HEAD');
				head[0].appendChild(style);
			} else {
				// 一番最後のスタイルシートを取得
				var tSheet = sheets[sheets.length-1];
				if ( document.all ) {
					// iIndexは省略可。省略するとスタイルシートの最後に追加
					tSheet.addRule( selector, declarations );
				} else {
					// ruleはセレクタと宣言ブロック。被挿入規則のインデックスが返る
					tSheet.insertRule( selector + '{' + declarations + '}', tSheet.cssRules.length );
				}
			}
		}
	},
	//-----------------------------------------
	// 画像リンクチェック（テキストリンクチェック）
	//-----------------------------------------
	checkTextLink : function ( element ) {
		var result = true;
		var children = element.childNodes;
		for (var i = 0, len = children.length; i < len; i++) {
			// 子要素にimg要素が含まれる場合
			if ( children[i].nodeType == '1' && children[i].nodeName.match(/IMG/i) ) {
				result = false;
				break;
			}
		}
		return result;
	},
	//-----------------------------------------
	// イベントに関数を付加する
	//-----------------------------------------
	addEvent : function( target, event, func ) {
		try {
			target.addEventListener(event, func, false);
		} catch (e) {
			target.attachEvent('on' + event, func);
		}
	}
}
// 実行
addIcon2Links.initialize();